import jwt
import requests

class Whalegistic:

	def __init__(this, public_key, private_key):
		this.pri_key = private_key;
		this.pub_key = public_key;
		this.token = jwt.encode({ public_key: public_key}, private_key, algorithm="HS256");



	def getBrands(this, send_obj):

		send_url = "https://whalegistic.com/api/get-brands"

		if send_obj == None: 
			send_obj = {}

		send_obj.public_key = this.pub_key

		send_headers = { 
			"Content-Type": "application/json", 
			"Authorization": f"Bearer {this.token}" 
		}

		brands_obj = requests.post(url = send_url, data = send_obj, headers = send_headers).json()

		print(f'BRANDS : {brands_obj}')

		return brands_obj.brands;



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.14'
DESCRIPTION = 'E-Commerce platform API'
LONG_DESCRIPTION = 'Whalegistic is a E-Commerce platform and this package is the connection between Whalegistic platform API and users websites'

setup(
    name="whalegistic",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author="<Whalegistic>",
    author_email="<info@whalegistic.com>",
    license='ISC',
    packages=find_packages(),
    install_requires=["pyjwt"],
    keywords="e-commerce, products, webstores, orders, pim, warehouse",
    classifiers= [
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 3",
    ]
)